OC.L10N.register(
    "photos",
    {
    "Photos" : "Photos",
    "Favorites" : "Favorites",
    "Shared with you" : "Shared with you",
    "Tags" : "ស្លាក",
    "Back" : "ត្រឡប់ក្រោយ",
    "Save" : "រក្សាទុក",
    "Shared by" : "បាន​ចែក​រំលែក​ដោយ",
    "Home" : "ទំព័រដើម",
    "General" : "ទូទៅ",
    "Remove from favorites" : "Remove from favorites",
    "Details" : "ព័ត៌មាន​លម្អិត",
    "Cancel" : "Cancel",
    "Add" : "បញ្ចូល"
},
"nplurals=1; plural=0;");
